ProductMD library documentation
===============================
ProductMD is a Python library providing parsers for metadata
related to composes and installation media.


Contents:

.. toctree::
    :maxdepth: 2
    
    terminology


Python modules:

.. toctree::
    :maxdepth: 2
    
    common
    compose
    composeinfo
    discinfo
    images
    rpms
    treeinfo


File formats:

.. toctree::
    :maxdepth: 2
    
    composeinfo-1.1
    discinfo-1.0
    images-1.1
    rpms-1.1
    treeinfo-1.1

Old file formats:

.. toctree::
    :maxdepth: 1
    
    composeinfo-1.0
    images-1.0
    rpms-1.0
    treeinfo-1.0


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

